@@ -103,7 +103,41 @@ impl Server {
             match backend {
                 Ok(backend) => backends.push(backend),
                 Err(err) => {
-                    log::error!("Failed to initialize backend: {:#}", err);
+                    #[allow(unused_mut)]
+                    let mut shown = false;
+
+                    #[cfg(feature = "gpg-agent")]
+                    use gpg_agent::sequoia_gpg_agent;
+
+                    #[cfg(feature = "gpg-agent")]
+                    if let Some(sequoia_gpg_agent::Error::GnuPG(
+                        sequoia_gpg_agent::gnupg::Error::GPGConfMissing))
+                        = err.downcast_ref()
+                    {
+                        log::info!("Failed to initialize backend: {:#}", err);
+                        shown = true;
+                    }
+
+                    #[cfg(feature = "gpg-agent")]
+                    if let Some(sequoia_gpg_agent::Error::GnuPG(
+                        sequoia_gpg_agent::gnupg::Error::ComponentMissing(_)))
+                        = err.downcast_ref()
+                    {
+                        log::info!("Failed to initialize backend: {:#}", err);
+                        shown = true;
+                    }
+
+                    #[cfg(feature = "gpg-agent")]
+                    if let Some(sequoia_gpg_agent::Error::GnuPGHomeMissing(_))
+                        = err.downcast_ref()
+                    {
+                        log::info!("Failed to initialize backend: {:#}", err);
+                        shown = true;
+                    }
+
+                    if ! shown {
+                        log::error!("Failed to initialize backend: {:#}", err);
+                    }
                 }
             }
         };
